import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:image_picker/image_picker.dart';

import '../bloc/feedback_bloc.dart';
import 'feedback_view.dart';

class FeedbackPage extends StatefulWidget {
  final Data data;

  const FeedbackPage({
    Key? key,
    required this.data,
  }) : super(key: key);

  @override
  State<FeedbackPage> createState() => _FeedbackPageState();
}

class _FeedbackPageState extends State<FeedbackPage> {
  late FeedbackBloc feedbackBloc;

  @override
  void initState() {
    super.initState();

    feedbackBloc = FeedbackBloc()..add(const FeedbackEvent.started());
  }

  @override
  void dispose() {
    feedbackBloc.close();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return BlocProvider<FeedbackBloc>.value(
      value: feedbackBloc,
      child: Scaffold(
        body: FeedbackView(
            onSend: (Map<String, dynamic> form) {
              feedbackBloc.add(
                FeedbackEvent.sending(form),
              );
            },
            onFileSend: (List<XFile> images) {
              feedbackBloc.add(FeedbackEvent.fileSending(images));
            },
            data: widget.data),
      ),
    );
  }
}

class Data {
  final String imageURL;
  final String hint;
  final bool addFile;
  final Color mainColor;
  final Color buttonTextColor;
  final Function onClose;

  Data({
    required this.imageURL,
    required this.hint,
    required this.addFile,
    required this.buttonTextColor,
    required this.mainColor,
    required this.onClose,
  });
}
