import 'package:flutter/material.dart';
import 'package:flutter_svg/svg.dart';

import '../common/widgets_style.dart';
import '../feedback/view/feedback_page.dart';

class SuccesfulSending extends StatelessWidget {
  final Data data;
  const SuccesfulSending({
    Key? key,
    required this.data,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Padding(
        padding: const EdgeInsets.symmetric(horizontal: 20),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: [
            Padding(
              padding: const EdgeInsets.only(top: 28),
              child: data.imageURL == ''
                  ? const Placeholder(
                      fallbackHeight: 40,
                    )
                  : Image(height: 40, image: NetworkImage(data.imageURL)),
            ),
            Column(
              children: [
                SvgPicture.asset(
                  'assets/icons/icon_star.svg',
                  color: data.mainColor,
                ),
                const SizedBox(
                  height: 16,
                ),
                const Text(
                  'Вы восхитительны!',
                  style: TextStyle(
                    fontSize: 20,
                    fontWeight: FontWeight.w600,
                  ),
                ),
                const SizedBox(
                  height: 12,
                ),
                const Text(
                  'Спасибо за обратную связь, проблема скоро будет решена',
                  textAlign: TextAlign.center,
                  style: TextStyle(
                    color: Color(0xFF6C6C6C),
                    fontSize: 14,
                    fontWeight: FontWeight.w400,
                  ),
                ),
              ],
            ),
            Padding(
              padding: const EdgeInsets.symmetric(vertical: 16),
              child: SizedBox(
                height: 55,
                width: double.infinity,
                child: ElevatedButton(
                  style: customButtonStyle(
                    color: data.mainColor,
                    textColor: data.buttonTextColor,
                  ),
                  onPressed: () {
                    data.onClose();
                  },
                  child: const Text(
                    'На главную',
                  ),
                ),
              ),
            ),
          ],
        ),
      ),
    );
  }
}
